powered by
vector of pastel colors
pastel.colors(num, seed=0)
number of colors
random number seed
vector of RGB hex colors
The seed is a value given so that the same pastel colors can be extracted with each subsequent call to the code.
rainbow
# NOT RUN { pastel.colors(12) pastel.colors(12, seed=1 ) # }
Run the code above in your browser using DataLab