powered by
Sepia Color Palette
sepia.colors(n, k = 1) hcl.colors(n, k = 260)
Number of colors
Sepia starting color, hcl ending number
vector of Octal color codes
There are two version of sepia in the code, each has a slightly different sepia end member.
tomo.colors, pastel.colors, syscolors, helpcolors
# NOT RUN { scol = sepia.colors(100) SHOWPAL(scol) see.pal(scol) # }
Run the code above in your browser using DataLab